@@ -28,14 +28,14 @@ class FileEventExtractor(object):
         # type: (iter, iter) -> None
         """Queries for recent security exposure events.
            Passes the raw response from the py42 call to `handlers.handle_response`.
-           The default implementation of `handlers.handle_response` prints `response.text` to the console.
-           Provide your own implementation for `handlers.handle_response` to do something else.
-           Makes subsequent calls to py42 and `handlers.handle_response`
-                if the total event count is greater than 10,000.
+           The default implementation of `handlers.handle_response` prints `response.text` to the
+           console. Provide your own implementation for `handlers.handle_response` to do something
+           else. Makes subsequent calls to py42 and `handlers.handle_response` if the total event
+           count is greater than 10,000.
 
         Args:
-            *args: Additional file event query filter groups. Note: Throws an exception if receives an
-                InsertionTimestamp filter.
+            *args: Additional file event query filter groups. Note: Throws an exception if
+            receives an InsertionTimestamp filter.
         """
         filter_groups = list(args)
         FileEventExtractor._verify_compatibility_of_filter_groups(filter_groups)
@@ -45,8 +45,7 @@ class FileEventExtractor(object):
         try:
             response = self._sdk.securitydata.search_file_events(query)
             if response.text:
-                response_dict = json.loads(response.text)
-                self._record_checkpoints(response_dict)
+                self._record_checkpoints(response)
                 self._handlers.handle_response(response)
             return response
         except Exception as ex:
@@ -91,30 +90,29 @@ class FileEventExtractor(object):
         if current_position:
             return InsertionTimestamp.on_or_after(current_position + _TIMESTAMP_PRECISION)
 
-    def _record_checkpoints(self, response_dict):
-        self._record_count(response_dict)
-        self._record_insertion_timestamp(response_dict)
+    def _record_checkpoints(self, response):
+        self._record_count(response)
+        self._record_insertion_timestamp(response)
 
-    def _record_count(self, response_dict):
-        total_count_key = u"totalCount"
-        count = response_dict[total_count_key] or 0
+    def _record_count(self, response):
+        count = response[u"totalCount"] or 0
         self._previous_event_count = count
 
-    def _record_insertion_timestamp(self, response_dict):
-        insertion_time = self._get_insertion_timestamp_from_dict(response_dict)
+    def _record_insertion_timestamp(self, response):
+        insertion_time = self._get_insertion_timestamp_from_response(response)
         if insertion_time is not None:
             self._handlers.record_cursor_position(insertion_time)
 
-    def _get_insertion_timestamp_from_dict(self, response_dict):
-        events = self._get_events_from_dict(response_dict)
+    def _get_insertion_timestamp_from_response(self, response):
+        events = self._get_events_from_response(response)
         if events and INSERTION_TIMESTAMP_FIELD_NAME in events[0]:
             return self._get_insertion_timestamp_from_event(events[0])
 
     @staticmethod
-    def _get_events_from_dict(response_dict):
+    def _get_events_from_response(response):
         file_events_key = u"fileEvents"
-        if file_events_key in response_dict:
-            return response_dict[file_events_key]
+        if file_events_key in response:
+            return response[file_events_key]
 
     @staticmethod
     def _get_insertion_timestamp_from_event(event):
